@@ -14,7 +14,7 @@ class TestSupportActions(unittest.TestCase):
     def test_account_support_access_name_override(self):
         name_override = "Access Granted for Okta Support"
         rule = okta.rules.account_support_access(
-            detection.RuleOptions(name=name_override)
+            overrides=detection.RuleOptions(name=name_override)
         )
 
         self.assertIsInstance(rule, detection.Rule)
@@ -22,7 +22,9 @@ class TestSupportActions(unittest.TestCase):
 
     def test_account_support_reset(self):
         name_override = "Override Name"
-        rule = okta.rules.support_reset(detection.RuleOptions(name=name_override))
+        rule = okta.rules.support_reset(
+            overrides=detection.RuleOptions(name=name_override)
+        )
 
         self.assertIsInstance(rule, detection.Rule)
         self.assertEqual(rule.name, name_override)
